{
  "type": "record",
  "Aspect": {
    "name": "glossaryNodeKey",
    "keyForEntity": "glossaryNode",
    "entityCategory": "core",
    "entityAspects": [
      "glossaryNodeInfo",
      "institutionalMemory",
      "ownership",
      "status",
      "structuredProperties",
      "forms",
      "testResults",
      "subTypes",
      "displayProperties",
      "assetSettings",
      "share",
      "origin"
    ]
  },
  "name": "GlossaryNodeKey",
  "namespace": "com.linkedin.pegasus2avro.metadata.key",
  "fields": [
    {
      "Searchable": {
        "enableAutocomplete": true,
        "fieldType": "WORD_GRAM"
      },
      "type": "string",
      "name": "name"
    }
  ],
  "doc": "Key for a GlossaryNode"
}